"use strict";

/* eslint-disable no-console */

import transform from 'css-to-react-native';
import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
const DEBUG = true;
function getThemeStyles(theme) {
  const styles = {};
  theme.tokenColors?.forEach(token => {
    if (!token.settings || !token.scope) return;
    const scopes = Array.isArray(token.scope) ? token.scope : typeof token.scope === 'string' ? token.scope.split(',').map(scope => scope.trim()) : [];
    const style = cleanStyle({
      color: token.settings.foreground,
      fontStyle: token.settings.fontStyle,
      fontWeight: token.settings.fontStyle === 'bold' ? 'bold' : 'normal'
    });
    scopes.forEach(scope => {
      styles[scope] = style;
    });
  });
  DEBUG && console.log('Theme styles:', styles);
  return styles;
}
function cleanStyle(style) {
  const filtered = Object.entries(style).filter(([_key, value]) => value != null).map(([key, value]) => [key, value]);
  DEBUG && console.log('Cleaning style:', style, 'Filtered:', filtered);
  return transform(filtered);
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const {
    tokens
  } = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme
  });
  const themeStyles = useMemo(() => getThemeStyles(theme), [theme]);
  const baseStyles = useMemo(() => {
    const styles = {
      scrollView: {
        flex: 1,
        minHeight: 20
      },
      codeContainer: {
        padding: 16,
        minWidth: '100%',
        backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e'
      },
      lineContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap'
      },
      token: {
        fontFamily: monospaceFont,
        fontSize: 14,
        color: theme.colors?.['editor.foreground'] || '#d4d4d4'
      }
    };
    return StyleSheet.create(styles);
  }, [theme]);
  const renderToken = (token, rowIndex, tokenIndex) => {
    const defaultStyle = baseStyles.token;
    const scopeStyles = token.explanation?.flatMap(exp => exp.scopes.map(scope => themeStyles[scope.toString()]).filter(Boolean)) || [];
    const specificStyle = token.color ? cleanStyle({
      color: token.color,
      fontStyle: token.fontStyle ? 'italic' : 'normal',
      fontWeight: token.fontStyle ? 'bold' : 'normal'
    }) : undefined;
    DEBUG && console.log('Token:', token, 'Scope styles:', scopeStyles);
    return /*#__PURE__*/_jsx(Text, {
      style: [defaultStyle, ...scopeStyles, specificStyle, textStyle, {
        fontSize
      }],
      children: token.content
    }, `${rowIndex}-${tokenIndex}`);
  };
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [baseStyles.scrollView, scrollViewProps?.style],
    contentContainerStyle: [baseStyles.codeContainer, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, rowIndex) => /*#__PURE__*/_jsx(View, {
        style: baseStyles.lineContainer,
        children: line.map((token, tokenIndex) => renderToken(token, rowIndex, tokenIndex))
      }, rowIndex))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map